@@ -7,8 +7,8 @@ from io import StringIO
 from typing import List
 from uuid import uuid4
 
-from kodexa.model import Document
 from kodexa.connectors import FolderConnector
+from kodexa.model import Document
 from kodexa_cloud import ContentObject
 
 
@@ -264,8 +264,11 @@ class Pipeline:
                     if self.stop_on_exception:
                         raise
 
-            document.log = log_stream.getvalue()
+            if document:
+                document.log = log_stream.getvalue()
+
             self.context.statistics.processed_document(document)
+            self.context.output_document = document
 
         logging.info(f"Completed pipeline {self.name}")
 
@@ -273,19 +276,15 @@ class Pipeline:
 
     @classmethod
     def from_url(cls, url, headers=None):
-        if headers is None:
-            headers = {}
-        url_document = Document()
-        url_document.metadata = {'connector': 'url', 'connector_options': {}}
-        url_document.metadata['connector_options']['url'] = url
-        url_document.metadata['connector_options']['headers'] = headers
-        return Pipeline(url_document)
+        return Pipeline(Document.from_url(url, headers))
 
     @classmethod
     def from_file(cls, file):
-        url_document = Document()
-        url_document.metadata = {'connector': 'file-handle', 'connector_options': {'file': file}}
-        return Pipeline(url_document)
+        return Pipeline(Document.from_file(file))
+
+    @classmethod
+    def from_text(cls, text):
+        return Pipeline(Document.from_text(text))
 
 
 class PipelineStatistics:
